==> gemrb-0.3.2.tar.gz: gemrb-0.3.2/gemrb/plugins/2DAImporter/2DAImp.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: 2DAImp.h 5439 2008-10-13 21:38:55Z avenger_teambg $
 *
 */

#ifndef P2DAIMP_H
#define P2DAIMP_H

#include <cstring>
#include "../Core/TableMgr.h"
#include "../../includes/globals.h"

typedef std::vector< char*> RowEntry;

class p2DAImp : public TableMgr {
private:
	DataStream* str;
	bool autoFree;
	std::vector< char*> colNames;
	std::vector< char*> rowNames;
	std::vector< char*> ptrs;
	std::vector< RowEntry> rows;
	char defVal[32];
public:
	p2DAImp(void);
	~p2DAImp(void);
	bool Open(DataStream* stream, bool autoFree = true);
	/** Returns the actual number of Rows in the Table */
	inline ieDword GetRowCount() const
	{
		return ( ieDword ) rows.size();
	}

	inline ieDword GetColNamesCount() const
	{
		return (ieDword) colNames.size();
	}

	/** Returns the actual number of Columns in the Table */
	inline ieDword GetColumnCount(unsigned int row = 0) const
	{
		if (rows.size() <= row) {
			return 0;
		}
		return ( ieDword ) rows[row].size();
	}
	/** Returns a pointer to a zero terminated 2da element,
		if it cannot return a value, it returns the default */
	inline const char* QueryField(unsigned int row = 0, unsigned int column = 0) const
	{
		if (rows.size() <= row) {
			return ( char * ) defVal;
		}
		if (rows[row].size() <= column) {
			return ( char * ) defVal;
		}
		if (rows[row][column][0]=='*' && !rows[row][column][1]) {
			return ( char * ) defVal;
		}
		return rows[row][column];
	};
	/** Returns a pointer to a zero terminated 2da element,
		 uses column name and row name to search the field */
	inline const char* QueryField(const char* row, const char* column) const
	{
		unsigned int i;

		int rowi = -1, coli = -1;
		for (i = 0; i < rowNames.size(); i++) {
			if (stricmp( rowNames[i], row ) == 0) {
				rowi = i;
				break;
			}
		}
		if (rowi == -1) {
			return ( char * ) defVal;
		}
		for (i = 0; i < colNames.size(); i++) {
			if (stricmp( colNames[i], column ) == 0) {
				coli = i;
				break;
			}
		}
		if (coli == -1) {
			return ( char * ) defVal;
		}
		if (rows[rowi].size() <= ( unsigned int ) coli) {
			return ( char * ) defVal;
		}
		if (rows[rowi][coli][0]=='*' && !rows[rowi][coli][1]) {
			return ( char *) defVal;
		}
		return rows[rowi][coli];
	};

	inline int GetRowIndex(const char* string) const
	{
		for (unsigned int index = 0; index < rowNames.size(); index++) {
			if (stricmp( rowNames[index], string ) == 0) {
				return index;
			}
		}
		return -1;
	};

	inline int GetColumnIndex(const char* string) const
	{
		for (unsigned int index = 0; index < colNames.size(); index++) {
			if (stricmp( colNames[index], string ) == 0) {
				return index;
			}
		}
		return -1;
	};

	inline const char* GetColumnName(unsigned int index) const
	{
		if (index < colNames.size()) {
			return colNames[index];
		}
		return "";
	};

	inline const char* GetRowName(unsigned int index) const
	{
		if (index < rowNames.size()) {
			return rowNames[index];
		}
		return "";
	};

	inline unsigned int FindTableValue(unsigned int col, long val, int start) const
  {
    ieDword row, max;
    
    max = GetRowCount();
    for (row = start; row < max; row++) {
      const char* ret = QueryField( row, col );
      long Value;
      if (valid_number( ret, Value ) && (Value == val) )
        return row;
    }
    return 0xffffffff;
  }

public:
	void release(void)
	{
		delete this;
	}
};

#endif

==> gemrb-0.6.0.tar.gz: gemrb-0.6.0/gemrb/plugins/2DAImporter/2DAImp.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $Id: 2DAImp.h 6005 2009-05-19 10:21:38Z lynxlupodian $
 *
 */

#ifndef P2DAIMP_H
#define P2DAIMP_H

#include <cstring>
#include "../Core/TableMgr.h"
#include "../../includes/globals.h"

typedef std::vector< char*> RowEntry;

class p2DAImp : public TableMgr {
private:
	DataStream* str;
	bool autoFree;
	std::vector< char*> colNames;
	std::vector< char*> rowNames;
	std::vector< char*> ptrs;
	std::vector< RowEntry> rows;
	char defVal[32];
public:
	p2DAImp(void);
	~p2DAImp(void);
	bool Open(DataStream* stream, bool autoFree = true);
	/** Returns the actual number of Rows in the Table */
	inline ieDword GetRowCount() const
	{
		return ( ieDword ) rows.size();
	}

	inline ieDword GetColNamesCount() const
	{
		return (ieDword) colNames.size();
	}

	/** Returns the actual number of Columns in the Table */
	inline ieDword GetColumnCount(unsigned int row = 0) const
	{
		if (rows.size() <= row) {
			return 0;
		}
		return ( ieDword ) rows[row].size();
	}
	/** Returns a pointer to a zero terminated 2da element,
		if it cannot return a value, it returns the default */
	inline const char* QueryField(unsigned int row = 0, unsigned int column = 0) const
	{
		if (rows.size() <= row) {
			return ( char * ) defVal;
		}
		if (rows[row].size() <= column) {
			return ( char * ) defVal;
		}
		if (rows[row][column][0]=='*' && !rows[row][column][1]) {
			return ( char * ) defVal;
		}
		return rows[row][column];
	};
	/** Returns a pointer to a zero terminated 2da element,
		 uses column name and row name to search the field */
	inline const char* QueryField(const char* row, const char* column) const
	{
		unsigned int i;

		int rowi = -1, coli = -1;
		for (i = 0; i < rowNames.size(); i++) {
			if (stricmp( rowNames[i], row ) == 0) {
				rowi = i;
				break;
			}
		}
		if (rowi == -1) {
			return ( char * ) defVal;
		}
		for (i = 0; i < colNames.size(); i++) {
			if (stricmp( colNames[i], column ) == 0) {
				coli = i;
				break;
			}
		}
		if (coli == -1) {
			return ( char * ) defVal;
		}
		if (rows[rowi].size() <= ( unsigned int ) coli) {
			return ( char * ) defVal;
		}
		if (rows[rowi][coli][0]=='*' && !rows[rowi][coli][1]) {
			return ( char *) defVal;
		}
		return rows[rowi][coli];
	};

	inline int GetRowIndex(const char* string) const
	{
		for (unsigned int index = 0; index < rowNames.size(); index++) {
			if (stricmp( rowNames[index], string ) == 0) {
				return index;
			}
		}
		return -1;
	};

	inline int GetColumnIndex(const char* string) const
	{
		for (unsigned int index = 0; index < colNames.size(); index++) {
			if (stricmp( colNames[index], string ) == 0) {
				return index;
			}
		}
		return -1;
	};

	inline const char* GetColumnName(unsigned int index) const
	{
		if (index < colNames.size()) {
			return colNames[index];
		}
		return "";
	};

	inline const char* GetRowName(unsigned int index) const
	{
		if (index < rowNames.size()) {
			return rowNames[index];
		}
		return "";
	};

	inline int FindTableValue(unsigned int col, long val, int start) const
	{
		ieDword row, max;
		
		max = GetRowCount();
		for (row = start; row < max; row++) {
			const char* ret = QueryField( row, col );
			long Value;
			if (valid_number( ret, Value ) && (Value == val) )
				return (int) row;
		}
		return -1;
	}

public:
	void release(void)
	{
		delete this;
	}
};

#endif
